<?php
/**
 * @file
 * File to add custom token.
 */
use Drupal\Core\Render\BubbleableMetadata;
use Drupal\entity_count_tokens\Controller\EntityCountTokensController;

/**
 * Implements hook_token_info().
 */
function entity_count_tokens_token_info() {
  $container = \Drupal::getContainer();
  $all_tokens = EntityCountTokensController::create($container)->generateAllTokens();
  $tokens = [];

  $types['entity_count_token'] = [
    'name' => t('Entity counts'),
    'description' => t('Define entity count tokens.'),
  ];

  foreach ($all_tokens as $token) {
    $tokens[$token] = [
      'name' => t('Entity Count Token'),
      'description' => t('Defined by its own name.'),
    ];
  }
  return [
    'types' => $types,
    'tokens' => ['entity' => $tokens],
  ];
}
/**
 * Implements hook_tokens().
 */
function entity_count_tokens_tokens($type, $tokens, array $data, array $options, BubbleableMetadata $bubbleable_metadata) {
  $replacements = [];
  if ($type == 'entity_count_token') {
    $container = \Drupal::getContainer();
    $entity_count = EntityCountTokensController::create($container)->entityCountRaw();

    foreach ($tokens as $name => $original) {
      $token_parts = explode(':', $name);
      $counter = $entity_count;
      foreach ($token_parts as $token_part) {
        $counter = $counter[$token_part];
      }
      $replacements[$original] = $counter;
    }
  }
  return $replacements;
}
